@@ -8,7 +8,7 @@ use PHP::HTTPBuildQuery qw(http_build_query);
 use MooX::Types::MooseLike::Base qw(Int InstanceOf Num Str);
 use Sub::Name;
 
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -173,7 +173,7 @@ sub _request {
   # build a POST request with json-encoded arguments
   my $post_args = $self->_build_query_args(%args);
   my $req = HTTP::Request->new('POST', $uri);
-  $req->content( uri_escape( $self->json->encode($post_args) ) );
+  $req->content( uri_escape_utf8( $self->json->encode($post_args) ) );
 
   my $response = $self->request( $req );
   return $response->is_success ? $self->json->decode($response->content) : $response->status_line;
